@@ -148,7 +148,7 @@ void Bookmarks::insertBookmark(BookmarkItem* parent, int row, BookmarkItem* item
 
     m_lastFolder = parent;
     m_model->addBookmark(parent, row, item);
-    emit bookmarkAdded(item);
+    Q_EMIT bookmarkAdded(item);
 
     m_autoSaver->changeOccurred();
 }
@@ -160,7 +160,7 @@ bool Bookmarks::removeBookmark(BookmarkItem* item)
     }
 
     m_model->removeBookmark(item);
-    emit bookmarkRemoved(item);
+    Q_EMIT bookmarkRemoved(item);
 
     m_autoSaver->changeOccurred();
     return true;
@@ -169,7 +169,7 @@ bool Bookmarks::removeBookmark(BookmarkItem* item)
 void Bookmarks::changeBookmark(BookmarkItem* item)
 {
     Q_ASSERT(item);
-    emit bookmarkChanged(item);
+    Q_EMIT bookmarkChanged(item);
 
     m_autoSaver->changeOccurred();
 }
@@ -177,14 +177,14 @@ void Bookmarks::changeBookmark(BookmarkItem* item)
 void Bookmarks::setShowOnlyIconsInToolbar(bool state)
 {
     m_showOnlyIconsInToolbar = state;
-    emit showOnlyIconsInToolbarChanged(state);
+    Q_EMIT showOnlyIconsInToolbarChanged(state);
     m_autoSaver->changeOccurred();
 }
 
 void Bookmarks::setShowOnlyTextInToolbar(bool state)
 {
     m_showOnlyTextInToolbar = state;
-    emit showOnlyTextInToolbarChanged(state);
+    Q_EMIT showOnlyTextInToolbarChanged(state);
     m_autoSaver->changeOccurred();
 }
 
@@ -322,7 +322,7 @@ void Bookmarks::readBookmarks(const QVariantList &list, BookmarkItem* parent)
 {
     Q_ASSERT(parent);
 
-    foreach (const QVariant &entry, list) {
+    for (const QVariant &entry : list) {
         const QVariantMap map = entry.toMap();
         BookmarkItem::Type type = BookmarkItem::typeFromString(map.value(QSL("type")).toString());
 
@@ -330,7 +330,7 @@ void Bookmarks::readBookmarks(const QVariantList &list, BookmarkItem* parent)
             continue;
         }
 
-        BookmarkItem* item = new BookmarkItem(type, parent);
+        auto* item = new BookmarkItem(type, parent);
 
         switch (type) {
         case BookmarkItem::Url:
@@ -364,7 +364,8 @@ QVariantList Bookmarks::writeBookmarks(BookmarkItem* parent)
 
     QVariantList list;
 
-    foreach (BookmarkItem* child, parent->children()) {
+    const auto children = parent->children();
+    for (BookmarkItem* child : children) {
         QVariantMap map;
         map.insert(QSL("type"), BookmarkItem::typeToString(child->type()));
 
@@ -405,11 +406,13 @@ void Bookmarks::search(QList<BookmarkItem*>* items, BookmarkItem* parent, const
 
     switch (parent->type()) {
     case BookmarkItem::Root:
-    case BookmarkItem::Folder:
-        foreach (BookmarkItem* child, parent->children()) {
+    case BookmarkItem::Folder: {
+        const auto children = parent->children();
+        for (BookmarkItem* child : children) {
             search(items, child, url);
         }
         break;
+    }
 
     case BookmarkItem::Url:
         if (parent->url() == url) {
@@ -433,11 +436,13 @@ void Bookmarks::search(QList<BookmarkItem*>* items, BookmarkItem* parent, const
 
     switch (parent->type()) {
     case BookmarkItem::Root:
-    case BookmarkItem::Folder:
-        foreach (BookmarkItem* child, parent->children()) {
+    case BookmarkItem::Folder: {
+        const auto children = parent->children();
+        for (BookmarkItem* child : children) {
             search(items, child, string, limit, sensitive);
         }
         break;
+    }
 
     case BookmarkItem::Url:
         if (parent->title().contains(string, sensitive) ||
@@ -461,10 +466,12 @@ void Bookmarks::searchKeyword(QList<BookmarkItem*>* items, BookmarkItem* parent,
 
     switch (parent->type()) {
     case BookmarkItem::Root:
-    case BookmarkItem::Folder:
-        foreach (BookmarkItem* child, parent->children())
+    case BookmarkItem::Folder: {
+        const auto children = parent->children();
+        for (BookmarkItem* child : children)
             searchKeyword(items, child, keyword);
         break;
+    }
 
     case BookmarkItem::Url:
         if (parent->keyword() == keyword)
