@@ -36,8 +36,8 @@ class FALKON_EXPORT DownloadOptionsDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit DownloadOptionsDialog(const QString &fileName, QWebEngineDownloadItem *downloadItem, QWidget* parent = 0);
-    ~DownloadOptionsDialog();
+    explicit DownloadOptionsDialog(const QString &fileName, QWebEngineDownloadItem *downloadItem, QWidget* parent = nullptr);
+    ~DownloadOptionsDialog() override;
 
     void showExternalManagerOption(bool show);
     void showFromLine(bool show);
