@@ -54,10 +54,13 @@ protected:
     QNetworkReply *createRequest(Operation op, const QNetworkRequest &request, QIODevice *outgoingData) override;
 
 private:
+    void saveIgnoredSslHosts();
+
     NetworkUrlInterceptor *m_urlInterceptor;
     ExtensionSchemeManager *m_extensionScheme;
     QHash<QString, QWebEngineCertificateError::Error> m_ignoredSslErrors;
     QHash<QString, QWebEngineCertificateError::Error> m_rejectedSslErrors;
+    QStringList m_ignoredSslHosts;
 };
 
 #endif // NETWORKMANAGER_H
