@@ -64,7 +64,9 @@ private Q_SLOTS:
     void openUserAgentManager();
     void openJsOptions();
     void openSearchEnginesManager();
+    void openCertificateManager();
     void openProtocolHandlersManager();
+    void openSchemesManager();
 
     void searchFromAddressBarChanged(bool state);
     void saveHistoryChanged(bool state);
