@@ -142,8 +142,8 @@ void WebView::setPage(WebPage *page)
 
     if (m_page) {
         if (m_page->isLoading()) {
-            emit m_page->loadProgress(100);
-            emit m_page->loadFinished(true);
+            Q_EMIT m_page->loadProgress(100);
+            Q_EMIT m_page->loadFinished(true);
         }
         mApp->plugins()->emitWebPageDeleted(m_page);
         m_page->setView(nullptr);
@@ -155,8 +155,8 @@ void WebView::setPage(WebPage *page)
     m_page = page;
 
     if (m_page->isLoading()) {
-        emit loadStarted();
-        emit loadProgress(m_page->m_loadProgress);
+        Q_EMIT loadStarted();
+        Q_EMIT loadProgress(m_page->m_loadProgress);
     }
 
     connect(m_page, &WebPage::privacyChanged, this, &WebView::privacyChanged);
@@ -171,7 +171,7 @@ void WebView::setPage(WebPage *page)
     // Scrollbars must be added only after QWebEnginePage is set
     WebScrollBarManager::instance()->addWebView(this);
 
-    emit pageChanged(m_page);
+    Q_EMIT pageChanged(m_page);
     mApp->plugins()->emitWebPageCreated(m_page);
 }
 
@@ -286,14 +286,14 @@ void WebView::setForceContextMenuOnMouseRelease(bool force)
 
 void WebView::addNotification(QWidget* notif)
 {
-    emit showNotification(notif);
+    Q_EMIT showNotification(notif);
 }
 
 void WebView::applyZoom()
 {
     setZoomFactor(qreal(zoomLevels().at(m_currentZoomLevel)) / 100.0);
 
-    emit zoomLevelChanged(m_currentZoomLevel);
+    Q_EMIT zoomLevelChanged(m_currentZoomLevel);
 }
 
 void WebView::zoomIn()
@@ -368,7 +368,7 @@ void WebView::back()
     if (history->canGoBack()) {
         history->back();
 
-        emit urlChanged(url());
+        Q_EMIT urlChanged(url());
     }
 }
 
@@ -379,7 +379,7 @@ void WebView::forward()
     if (history->canGoForward()) {
         history->forward();
 
-        emit urlChanged(url());
+        Q_EMIT urlChanged(url());
     }
 }
 
@@ -387,11 +387,11 @@ void WebView::printPage()
 {
     Q_ASSERT(m_page);
 
-    QPrinter *printer = new QPrinter();
+    auto *printer = new QPrinter();
     printer->setCreator(tr("Falkon %1 (%2)").arg(Qz::VERSION, Qz::WWWADDRESS));
     printer->setDocName(QzTools::filterCharsFromFilename(title()));
 
-    QPrintDialog *dialog = new QPrintDialog(printer, this);
+    auto *dialog = new QPrintDialog(printer, this);
     dialog->setOptions(QAbstractPrintDialog::PrintToFile | QAbstractPrintDialog::PrintShowPageSize);
 #ifndef Q_OS_WIN
     dialog->setOption(QAbstractPrintDialog::PrintPageRange);
@@ -416,7 +416,7 @@ void WebView::slotLoadStarted()
     m_progress = 0;
 
     if (title(/*allowEmpty*/true).isEmpty()) {
-        emit titleChanged(title());
+        Q_EMIT titleChanged(title());
     }
 }
 
@@ -451,7 +451,7 @@ void WebView::slotUrlChanged(const QUrl &url)
         // Don't treat this as background activity change
         const bool oldActivity = m_backgroundActivity;
         m_backgroundActivity = true;
-        emit titleChanged(title());
+        Q_EMIT titleChanged(title());
         m_backgroundActivity = oldActivity;
     }
 }
@@ -462,20 +462,20 @@ void WebView::slotTitleChanged(const QString &title)
 
     if (!isVisible() && !isLoading() && !m_backgroundActivity) {
         m_backgroundActivity = true;
-        emit backgroundActivityChanged(m_backgroundActivity);
+        Q_EMIT backgroundActivityChanged(m_backgroundActivity);
     }
 }
 
 void WebView::openUrlInNewWindow()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         mApp->createWindow(Qz::BW_NewWindow, action->data().toUrl());
     }
 }
 
 void WebView::sendTextByMail()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         const QUrl mailUrl = QUrl::fromEncoded("mailto:%20?body=" + QUrl::toPercentEncoding(action->data().toString()));
         QDesktopServices::openUrl(mailUrl);
     }
@@ -489,14 +489,13 @@ void WebView::sendPageByMail()
 
 void WebView::copyLinkToClipboard()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         QApplication::clipboard()->setText(action->data().toUrl().toEncoded());
     }
 }
 
 void WebView::savePageAs()
 {
-#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     page()->runJavaScript(QSL("document.contentType"), WebPage::SafeJsWorld, [this](const QVariant &res) {
         const QSet<QString> webPageTypes = {
             QSL("text/html"),
@@ -508,9 +507,6 @@ void WebView::savePageAs()
             page()->download(url());
         }
     });
-#else
-    triggerPageAction(QWebEnginePage::SavePage);
-#endif
 }
 
 void WebView::copyImageToClipboard()
@@ -540,7 +536,7 @@ void WebView::openUrlInNewTab(const QUrl &url, Qz::NewTabPositionFlags position)
 
 void WebView::openActionUrl()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         load(action->data().toUrl());
     }
 }
@@ -560,14 +556,14 @@ void WebView::showSource()
 
 void WebView::showSiteInfo()
 {
-    SiteInfo* s = new SiteInfo(this);
+    auto* s = new SiteInfo(this);
     s->show();
 }
 
 void WebView::searchSelectedText()
 {
     SearchEngine engine = mApp->searchEnginesManager()->defaultEngine();
-    if (QAction* act = qobject_cast<QAction*>(sender())) {
+    if (auto* act = qobject_cast<QAction*>(sender())) {
         if (act->data().isValid()) {
             engine = act->data().value<SearchEngine>();
         }
@@ -580,7 +576,7 @@ void WebView::searchSelectedText()
 void WebView::searchSelectedTextInBackgroundTab()
 {
     SearchEngine engine = mApp->searchEnginesManager()->defaultEngine();
-    if (QAction* act = qobject_cast<QAction*>(sender())) {
+    if (auto* act = qobject_cast<QAction*>(sender())) {
         if (act->data().isValid()) {
             engine = act->data().value<SearchEngine>();
         }
@@ -592,7 +588,7 @@ void WebView::searchSelectedTextInBackgroundTab()
 
 void WebView::bookmarkLink()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         if (action->data().isNull()) {
             BookmarksTools::addBookmarkDialog(this, url(), title());
         }
@@ -607,14 +603,14 @@ void WebView::bookmarkLink()
 
 void WebView::openUrlInSelectedTab()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         openUrlInNewTab(action->data().toUrl(), Qz::NT_CleanSelectedTab);
     }
 }
 
 void WebView::openUrlInBackgroundTab()
 {
-    if (QAction* action = qobject_cast<QAction*>(sender())) {
+    if (auto* action = qobject_cast<QAction*>(sender())) {
         openUrlInNewTab(action->data().toUrl(), Qz::NT_CleanNotSelectedTab);
     }
 }
@@ -638,7 +634,7 @@ void WebView::userDefinedOpenUrlInNewTab(const QUrl &url, bool invert)
     if (!url.isEmpty()) {
         actionUrl = url;
     }
-    else if (QAction* action = qobject_cast<QAction*>(sender())) {
+    else if (auto* action = qobject_cast<QAction*>(sender())) {
         actionUrl = action->data().toUrl();
     }
 
@@ -652,7 +648,7 @@ void WebView::userDefinedOpenUrlInBgTab(const QUrl &url)
     if (!url.isEmpty()) {
         actionUrl = url;
     }
-    else if (QAction* action = qobject_cast<QAction*>(sender())) {
+    else if (auto* action = qobject_cast<QAction*>(sender())) {
         actionUrl = action->data().toUrl();
     }
 
@@ -665,7 +661,7 @@ void WebView::showEvent(QShowEvent *event)
 
     if (m_backgroundActivity) {
         m_backgroundActivity = false;
-        emit backgroundActivityChanged(m_backgroundActivity);
+        Q_EMIT backgroundActivityChanged(m_backgroundActivity);
     }
 }
 
@@ -796,7 +792,7 @@ void WebView::createPageContextMenu(QMenu* menu)
 void WebView::createLinkContextMenu(QMenu* menu, const WebHitTestResult &hitTest)
 {
     menu->addSeparator();
-    Action* act = new Action(IconProvider::newTabIcon(), tr("Open link in new &tab"));
+    auto* act = new Action(IconProvider::newTabIcon(), tr("Open link in new &tab"));
     act->setData(hitTest.linkUrl());
     connect(act, SIGNAL(triggered()), this, SLOT(userDefinedOpenUrlInNewTab()));
     connect(act, SIGNAL(ctrlTriggered()), this, SLOT(userDefinedOpenUrlInBgTab()));
@@ -824,7 +820,7 @@ void WebView::createImageContextMenu(QMenu* menu, const WebHitTestResult &hitTes
 {
     menu->addSeparator();
     if (hitTest.imageUrl() != url()) {
-        Action *act = new Action(tr("Show i&mage"));
+        auto *act = new Action(tr("Show i&mage"));
         act->setData(hitTest.imageUrl());
         connect(act, &QAction::triggered, this, &WebView::openActionUrl);
         connect(act, SIGNAL(ctrlTriggered()), this, SLOT(userDefinedOpenUrlInNewTab()));
@@ -865,7 +861,7 @@ void WebView::createSelectedTextContextMenu(QMenu* menu, const WebHitTestResult
     QUrl guessedUrl = QUrl::fromUserInput(selectedString);
 
     if (isUrlValid(guessedUrl)) {
-        Action* act = new Action(QIcon::fromTheme("document-open-remote"), tr("Go to &web address"));
+        auto* act = new Action(QIcon::fromTheme("document-open-remote"), tr("Go to &web address"));
         act->setData(guessedUrl);
 
         connect(act, &QAction::triggered, this, &WebView::openActionUrl);
@@ -879,7 +875,7 @@ void WebView::createSelectedTextContextMenu(QMenu* menu, const WebHitTestResult
     selectedText.replace(QLatin1Char('\n'), QLatin1Char(' ')).replace(QLatin1Char('\t'), QLatin1Char(' '));
 
     SearchEngine engine = mApp->searchEnginesManager()->defaultEngine();
-    Action* act = new Action(engine.icon, tr("Search \"%1 ..\" with %2").arg(selectedText, engine.name));
+    auto* act = new Action(engine.icon, tr("Search \"%1 ..\" with %2").arg(selectedText, engine.name));
     connect(act, &QAction::triggered, this, &WebView::searchSelectedText);
     connect(act, &Action::ctrlTriggered, this, &WebView::searchSelectedTextInBackgroundTab);
     menu->addAction(act);
@@ -890,7 +886,7 @@ void WebView::createSelectedTextContextMenu(QMenu* menu, const WebHitTestResult
     SearchEnginesManager* searchManager = mApp->searchEnginesManager();
     const auto engines = searchManager->allEngines();
     for (const SearchEngine &en : engines) {
-        Action* act = new Action(en.icon, en.name);
+        auto* act = new Action(en.icon, en.name);
         act->setData(QVariant::fromValue(en));
 
         connect(act, &QAction::triggered, this, &WebView::searchSelectedText);
@@ -1232,7 +1228,7 @@ void WebView::_contextMenuEvent(QContextMenuEvent *event)
 void WebView::resizeEvent(QResizeEvent *event)
 {
     QWebEngineView::resizeEvent(event);
-    emit viewportResized(size());
+    Q_EMIT viewportResized(size());
 }
 
 void WebView::contextMenuEvent(QContextMenuEvent *event)
@@ -1252,14 +1248,6 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
 
 bool WebView::focusNextPrevChild(bool next)
 {
-#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 11, 0)
-    // QTBUG-67043
-    // Workaround QtWebEngine issue where QWebEngineView loses focus on second load() call.
-    if (next) {
-        setFocus();
-        return false;
-    }
-#endif
     return QWebEngineView::focusNextPrevChild(next);
 }
 
@@ -1277,18 +1265,12 @@ bool WebView::eventFilter(QObject *obj, QEvent *event)
 
     // Hack to find widget that receives input events
     if (obj == this && event->type() == QEvent::ChildAdded) {
-#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 12, 0)
         QPointer<QWidget> child = qobject_cast<QWidget*>(static_cast<QChildEvent*>(event)->child());
         QTimer::singleShot(0, this, [=]() {
             if (child && child->inherits("QtWebEngineCore::RenderWidgetHostViewQtDelegateWidget")) {
                 m_rwhvqt = child;
-#else
-        QTimer::singleShot(0, this, [this]() {
-            if (focusProxy() && m_rwhvqt != focusProxy()) {
-                m_rwhvqt = focusProxy();
-#endif
                 m_rwhvqt->installEventFilter(this);
-                if (QQuickWidget *w = qobject_cast<QQuickWidget*>(m_rwhvqt)) {
+                if (auto *w = qobject_cast<QQuickWidget*>(m_rwhvqt)) {
                     w->setClearColor(palette().color(QPalette::Window));
                 }
             }
@@ -1367,7 +1349,7 @@ bool WebView::eventFilter(QObject *obj, QEvent *event)
         switch (event->type()) {
         case QEvent::FocusIn:
         case QEvent::FocusOut:
-            emit focusChanged(hasFocus());
+            Q_EMIT focusChanged(hasFocus());
             break;
 
         default:
